Raxol.Agent.Comm (Raxol v2.3.0)

Agent communication primitives.

Agents discover each other via Raxol.Agent.Registry and communicate through their Session GenServers. Messages arrive in the target agent's update/2 as {:agent_message, from_id, payload}.

Summary

Functions

Broadcast a message to all agents in a team.

Synchronous request-reply with another agent.

Send an async message to another agent by id.

Functions

broadcast_team(team_id, message)

Broadcast a message to all agents in a team.

call(target_id, message, timeout \\ 5000)

Synchronous request-reply with another agent.

send(target_id, message)

Send an async message to another agent by id.