Raxol.Core.Behaviours.BaseManager behaviour
(Raxol v2.3.0)
Base behavior for manager GenServers to reduce code duplication. Provides common patterns for state management, lifecycle, and error handling.
Summary
Callbacks
Called to handle manager-specific requests.
Called to handle manager-specific casts.
Called to handle manager-specific info messages.
Called to initialize the manager state. Must return {:ok, state}. For initialization failures, raise an exception to let the supervisor handle restart logic.
Callbacks
@callback handle_manager_call(any(), GenServer.from(), any()) :: {:reply, any(), any()} | {:noreply, any()} | {:stop, any(), any(), any()}
Called to handle manager-specific requests.
Called to handle manager-specific casts.
Called to handle manager-specific info messages.
Called to initialize the manager state. Must return {:ok, state}. For initialization failures, raise an exception to let the supervisor handle restart logic.