Raxol.Terminal.ANSI.CharacterSets.Translator (Raxol v2.3.0)

Handles character set translations and mappings. Delegates per-charset data lookups to CharsetData.

Summary

Functions

Translates a character using the active character set (2-parameter version). Returns a tuple of {translated_char, new_charset_state}.

Translates a character using the named character set and optional single shift.

Translates a string using the specified character set and single shift.

Functions

translate_char(codepoint, state)

Translates a character using the active character set (2-parameter version). Returns a tuple of {translated_char, new_charset_state}.

translate_char(codepoint, active_set, single_shift)

Translates a character using the named character set and optional single shift.

translate_string(string, charset, single_shift)

Translates a string using the specified character set and single shift.