Raxol.Terminal.Buffer.LineOperations.Management (Raxol v2.3.0)

Line management operations for terminal buffers. Handles line creation, retrieval, and manipulation.

Summary

Functions

Clear a line to spaces.

Create an empty line with the given width.

Create multiple empty lines.

Get a line from the buffer.

Remove lines from the top of the buffer.

Add blank lines or provided lines to the beginning of the buffer.

Set a line in the buffer.

Update a line with a function.

Functions

clear_line(buffer, y, style \\ %{})

Clear a line to spaces.

create_empty_line(width, style)

Create an empty line with the given width.

create_empty_lines(count, width)

Create multiple empty lines.

create_empty_lines(count, width, style)

get_line(buffer, y)

Get a line from the buffer.

pop_top_lines(buffer, count)

Remove lines from the top of the buffer.

prepend_lines(buffer, count)

Add blank lines or provided lines to the beginning of the buffer.

set_line(buffer, y, line)

Set a line in the buffer.

update_line(buffer, y, fun)

Update a line with a function.